@@ -7,7 +7,23 @@
 #endif
 
 #include "charpick.h"
-#include <egg-screen-help.h>
+
+#include <string.h>
+
+#include <atk/atkrelation.h>
+#include <gtk/gtkaccessible.h>
+#include <gtk/gtkbox.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkiconfactory.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkliststore.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkvbox.h>
+#include <libgnomeui/gnome-help.h>
 
 #define CHARPICK_STOCK_EDIT "charpick-stock-edit"
 
@@ -20,7 +36,7 @@ register_stock_for_edit (void)
     GtkIconFactory *factory;
     GtkIconSet     *icons;
                                                                                 
-    static GtkStockItem edit_item [] = {
+    static const GtkStockItem edit_item [] = {
            { CHARPICK_STOCK_EDIT, N_("_Edit"), 0, 0, GETTEXT_PACKAGE },
     };
     icons = gtk_icon_factory_lookup_default (GTK_STOCK_PREFERENCES);
@@ -32,6 +48,7 @@ register_stock_for_edit (void)
   }
 }
 
+#if 0
 static void
 set_atk_relation (GtkWidget *label, GtkWidget *widget)
 {
@@ -58,6 +75,7 @@ set_atk_relation (GtkWidget *label, GtkWidget *widget)
   atk_relation_set_add (relation_set, relation);
   g_object_unref (G_OBJECT (relation)); 
 }
+#endif /* 0 */
 
 /* sets accessible name and description */
 
@@ -84,8 +102,6 @@ add_edit_dialog_create (charpick_data *curr_data, gchar *string, gchar *title)
 	GtkWidget *dbox;
 	GtkWidget *vbox, *hbox;
 	GtkWidget *label;
-	gint retval;
-	gchar *new;
 
 	dialog = gtk_dialog_new_with_buttons (_(title), GTK_WINDOW (curr_data->propwindow),
 							    GTK_DIALOG_DESTROY_WITH_PARENT |
@@ -311,7 +327,6 @@ delete_palette (GtkButton *button, charpick_data *curr_data)
 	if (g_ascii_strcasecmp (curr_data->charlist, charlist) == 0) {
 		curr_data->charlist = curr_data->chartable != NULL ? 
 				      curr_data->chartable->data : "";
-		build_table (curr_data);
 		if (key_writable (PANEL_APPLET (curr_data->applet), "current_list"))
 			panel_applet_gconf_set_string (PANEL_APPLET (curr_data->applet), "current_list", curr_data->charlist, NULL);
 	}
@@ -497,7 +512,7 @@ phelp_cb (GtkDialog *dialog, gint tab, gpointer data)
 {
   GError *error = NULL;
 
-  egg_help_display_on_screen (
+  gnome_help_display_on_screen (
 		"char-palette", "charpick-prefs",
 		gtk_window_get_screen (GTK_WINDOW (dialog)),
 		&error);
